Contact Us: Help Make Mocavo Even Better
Description: If you have any questions or feedback for the Mocavo team, please get in touch with us. We will do our best to help you out in any way that we can.

# Help Us Make Mocavo Even Better

Many of our common questions relating to billing and the features of Mocavo Gold vs. Mocavo Basic are conveniently answered on our Help page. You may be able to find an easy resolution to your question, so please take a quick look.

If you would like help getting started on Mocavo, please visit our Learning Center for many helpful articles and tips on using our website.

If you would like to cancel your Mocavo Gold account or end your 7-day Free Trial, please complete the form below. If you have a free Mocavo Basic account, there is no need to cancel since there is no charge.

If you have a Mocavo Basic account and would like to learn more about our premium service, Mocavo Gold, please visit www.mocavo.com/plus.

If you are receiving too many emails from us, please visit your Email Settings to change your preferences.

We have a 24 hour response time Monday through Friday. If you are emailing us over the weekend, we will respond on Monday.

Our social media communities are also a great resource for common questions relating to Mocavo.

- Facebook
- Pinterest
- Google+
- Twitter

## Contact Us

If you have any questions or feedback for the Mocavo team, please get in touch with us. We'll do our best to answer your questions or help you out in any way that we can. Thank you.

Subject

Please fill out all of the fields before submitting.

Your Name

Please fill out all of the fields before submitting.

Your E-Mail

Please fill out all of the fields before submitting.

Message

Please fill out all of the fields before submitting.

Human Verification

We will do our best to answer your question within 24 hours. Please submit only one Contact Form.

Please fill out all of the fields before submitting.

## Upload Your Story with Mocavo

- ##

  ### Upload
  a Tree

- ##

  ### Upload
  a Document

- ##

  ### Upload
  a Database

## Upload Your Family Tree

- ##

  ### Upload
  from Desktop

## Upload a Document

- ##

  ### Upload
  from Desktop

### Select Family Tree File (Step 1 of 2)

Choose File from Your Computer

### Upload a Family Tree (Step 2 of 2)

Give this Tree a Name

### Upload a Document (Step 1 of 2)

Choose File

### Suggest a Site

We are always on the lookout for new resources to add to our database. If you have a website that you believe would benefit our community, please let us know.

Website URL (please provide a URL)
Your Email (please provide a valid email)
Brief Description (please provide a brief description)

### Upload a Database

We are always on the lookout for new records to add to our database. If you have a resource that you would like to contribute to our community, please let us know and we will be in touch as soon as possible.

Your Name Your E-Mail Please Describe Your Database Please Categorize Your Database